==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/AnchoredRadialSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialBaseDescriptionMetadata } from "./RadialBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AnchoredRadialSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnchoredRadialSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (AnchoredRadialSeriesDescriptionMetadata.a == null) {
                AnchoredRadialSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnchoredRadialSeriesDescriptionMetadata.c(AnchoredRadialSeriesDescriptionMetadata.a);
            }
            if (a.j(AnchoredRadialSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(AnchoredRadialSeriesDescriptionMetadata.a);
        }
        static c(a) {
            RadialBaseDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLinePeriod", "Number:int");
            a.item("TrendLineZIndex", "Number:int");
        }
        static d(a) {
            AnchoredRadialSeriesDescriptionMetadata.b(a);
            a.z("AnchoredRadialSeries", AnchoredRadialSeriesDescriptionMetadata.a);
        }
    }
    AnchoredRadialSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(AnchoredRadialSeriesDescriptionMetadata, 'AnchoredRadialSeriesDescriptionMetadata');
    AnchoredRadialSeriesDescriptionMetadata.a = null;
    return AnchoredRadialSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AnchoredRadialSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RadialBaseDescriptionMetadata } from "./RadialBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AnchoredRadialSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class AnchoredRadialSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (AnchoredRadialSeriesDescriptionMetadata.a == null) {
                AnchoredRadialSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AnchoredRadialSeriesDescriptionMetadata.c(AnchoredRadialSeriesDescriptionMetadata.a);
            }
            if (a.k(AnchoredRadialSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(AnchoredRadialSeriesDescriptionMetadata.a);
        }
        static c(a) {
            RadialBaseDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberAsLegendLabel", "String");
            a.item("ValueMemberAsLegendUnit", "String");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLinePeriod", "Number:int");
            a.item("TrendLineZIndex", "Number:int");
        }
        static d(a) {
            AnchoredRadialSeriesDescriptionMetadata.b(a);
            a.ab("AnchoredRadialSeries", AnchoredRadialSeriesDescriptionMetadata.a);
        }
    }
    AnchoredRadialSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(AnchoredRadialSeriesDescriptionMetadata, 'AnchoredRadialSeriesDescriptionMetadata');
    AnchoredRadialSeriesDescriptionMetadata.a = null;
    return AnchoredRadialSeriesDescriptionMetadata;
})();
